Coloring multimethods to format text by adding markup.
:print-color
When true, ouptut colored text from print functions.
:color-markup
:ansi for color terminal text (default):html-inline for inline-styled html:html-classes for html with semantic classes:color-scheme
Map of syntax element keywords to color codes.
Coloring multimethods to format text by adding markup. #### Color Options `:print-color` When true, ouptut colored text from print functions. `:color-markup` - `:ansi` for color terminal text (default) - `:html-inline` for inline-styled html - `:html-classes` for html with semantic classes `:color-scheme` Map of syntax element keywords to color codes.
(dispatch options element text)Dispatches to coloring multimethods. Element should be a key from the color-scheme map.
Dispatches to coloring multimethods. Element should be a key from the color-scheme map.
Constructs a pretty print document, which may be colored if
:print-color is true.
Constructs a pretty print document, which may be colored if `:print-color` is true.
Produces text colored according to the active color scheme. This is mostly
useful to clients which want to produce output which matches data printed by
Puget, but which is not directly printed by the library. Note that this
function still obeys the :print-color option.
Produces text colored according to the active color scheme. This is mostly useful to clients which want to produce output which matches data printed by Puget, but which is not directly printed by the library. Note that this function still obeys the `:print-color` option.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |